# requests-gracedb

requests-gracedb provides a generic REST API client for [GraceDB] and similar
LIGO/Virgo API services. It uses the powerful [Requests] package for reliable
and high-throughput HTTP connection pooling.

[GraceDB]: https://gracedb.ligo.org/
[Requests]: http://requests.readthedocs.io/

## Notes for software packaging

Software packaging files exist for the following systems:

- RPM: https://git.ligo.org/packaging/rhel/python-requests-gracedb
- Debian: https://git.ligo.org/packaging/debian/requests-gracedb
- Conda: https://github.com/conda-forge/requests-gracedb-feedstock
